package controllers

import (
	"errors"
	"net/url"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
)

// GetWxJsSDKSignature 获取 微信 jssdk 签名
func (c *BaseController) GetWxJsSDKSignature() {
	org := c.Context.Get("org").(model.SysOrg)
	url, _ := url.QueryUnescape(c.GetString("url"))

	cli := utils.WxClientFor(org.OrgId)
	if cli == nil {
		c.ResponseError(errors.New("初始化微信服务失败"))
	}

	res := cli.GetJsTicketSignature(url)
	c.ResponseJSON(res)
}

// MiniLogin 获取小程序 OPENID
func (c *BaseController) MiniLogin() {
	org := c.Context.Get("org").(model.SysOrg)
	code := c.GetString("code")

	cli := utils.MiniClientFor(org.OrgId)
	if cli == nil {
		c.ResponseError(errors.New("初始化小程序服务失败"))
	}

	res, err := cli.GetOpenID(code)
	if err != nil {
		utils.LogError("获取用户信息失败: " + err.Error())
		c.ResponseError(errors.New("获取用户信息失败"))
	}

	c.ResponseJSON(res)
}

// DecodeMiniData 解密小程序信息
func (c *BaseController) DecodeMiniData() {
	org := c.Context.Get("org").(model.SysOrg)

	cli := utils.MiniClientFor(org.OrgId)
	if cli == nil {
		c.ResponseError(errors.New("初始化小程序服务失败"))
	}

	data := c.GetString("encrypted_data")
	key := c.GetString("session_key")
	iv := c.GetString("iv")

	res, err := cli.GetUserFromEncryptData(data, key, iv)
	if err != nil {
		utils.LogError("解密用户信息失败: " + err.Error())
		c.ResponseError(errors.New("解密用户信息失败"))
	}

	c.ResponseJSON(res)
}
